@@ -27,7 +27,8 @@
 enum hnb_vty_nodes {
 	HNODEB_NODE = _LAST_OSMOVTY_NODE,
 	IUH_NODE,
-	CHAN_NODE,
+	LLSK_NODE,
+	GTP_NODE,
 };
 
 void hnb_vty_init(void);
